function SentryGunBase.spawn(owner, pos, rot, peer_id, verify_equipment, unit_idstring_index, fire_mode_index)
	local attached_data = SentryGunBase._attach(pos, rot)

	if not attached_data then
		Application:error("[SentryGunBase.spawn] Failed attaching sentry gun", owner, pos, rot, peer_id, verify_equipment, unit_idstring_index)

		return
	end

	if verify_equipment and not managers.player:verify_equipment(peer_id, "sentry_gun") then
		Application:error("[SentryGunBase.spawn] Player equipment verification failed", owner, pos, rot, peer_id, verify_equipment, unit_idstring_index)

		return
	end

	local sentry_owner = nil

	if owner and owner:base().upgrade_value then
		sentry_owner = owner
	end

	local player_skill = PlayerSkill
	local ammo_multiplier = player_skill.skill_data("sentry_gun", "extra_ammo_multiplier", 1, sentry_owner)
	local armor_multiplier = 1 + player_skill.skill_data("sentry_gun", "armor_multiplier", 1, sentry_owner) - 1 + player_skill.skill_data("sentry_gun", "armor_multiplier2", 1, sentry_owner) - 1
	local spread_level = player_skill.skill_data("sentry_gun", "spread_multiplier", 1, sentry_owner)
	local rot_speed_level = player_skill.skill_data("sentry_gun", "rot_speed_multiplier", 1, sentry_owner)
	local ap_bullets = player_skill.has_skill("sentry_gun", "ap_bullets", sentry_owner)
	local has_shield = player_skill.has_skill("sentry_gun", "shield", sentry_owner)
	local id_string = Idstring("units/payday2/equipment/gen_equipment_sentry/gen_equipment_sentry")

	if unit_idstring_index then
		id_string = tweak_data.equipments.sentry_id_strings[unit_idstring_index]
	end

	local unit = World:spawn_unit(id_string, pos, rot)
	local spread_multiplier = 1
	local rot_speed_multiplier = 1

	managers.network:session():send_to_peers_synched("sync_equipment_setup", unit, 0, peer_id or 0)

	ammo_multiplier = SentryGunBase.AMMO_MUL[ammo_multiplier]

	unit:base():setup(owner, ammo_multiplier, armor_multiplier, spread_multiplier, rot_speed_multiplier, has_shield, attached_data, fire_mode_index)

	local owner_id = unit:base():get_owner_id()

	if ap_bullets and owner_id then
		local fire_mode_unit = World:spawn_unit(Idstring("units/payday2/equipment/gen_equipment_sentry/gen_equipment_sentry_fire_mode"), unit:position(), unit:rotation())

		unit:weapon():interaction_setup(fire_mode_unit, owner_id)
		managers.network:session():send_to_peers_synched("sync_fire_mode_interaction", unit, fire_mode_unit, owner_id)
	end

	local team = nil

	if owner then
		team = owner:movement():team()
	else
		team = managers.groupai:state():team_data(tweak_data.levels:get_default_team_ID("player"))
	end

	unit:movement():set_team(team)
	unit:brain():set_active(true)

	SentryGunBase.deployed = (SentryGunBase.deployed or 0) + 1

	return unit, spread_level, rot_speed_level
end